#!/bin/bash

ACTION=$1

CONFIG_FILE=${HOME}/.config/tuxum-config

###
###
### Activate recently plugged monitor: xrandr --output HDMI-1 --auto
### See: xrandr --listmonitors
### and xrandr --listactivemonitors
###
###

usage()
{
	echo "Usage: $0 <action>"
	echo "where action can be one of: duplicate, extend, screencount, lastaction"
	echo "Example:"
	echo "  $0 duplicate"
	exit 1
}

maxmode()
{
	MODE="0x0"
	for i in $(xrandr | grep "^ " | awk '{print $1}' | sort -nr)
	do
		if [ "${MODE}" == "${i}" ]
		then
			break
		else
			MODE=$i
		fi
	done
	echo ${MODE}
}

if [ -z "${ACTION}" ] || [ -n "$2" ]
then
	usage
fi

MONITORCOUNT=$(xrandr --listmonitors | grep -v "Monitors:" | awk '{print $2}' | wc -l)
ACTIVEMONITORCOUNT=$(xrandr --listactivemonitors | grep -v "Monitors:" | awk '{print $2}' | wc -l)

if [ ${MONITORCOUNT} -le 1 ]
then
	xrandr --auto
	MONITORCOUNT=$(xrandr --listmonitors | grep -v "Monitors:" | awk '{print $2}' | wc -l)
fi

if [ "${ACTION}" == "screencount" ]
then
	echo ${MONITORCOUNT}
	exit 0
fi

if [ "${ACTION}" == "lastaction" ]
then
	if [ -e ${CONFIG_FILE} ]
	then
		CONFIG=`cat ${CONFIG_FILE} | grep -i "Multimon=" | awk -F '=' '{print $2}'`
		if [ -n "${CONFIG}" ]
		then
			ACTION=${CONFIG}
		fi
	else
		exit 0
	fi
fi

if [ ${MONITORCOUNT} -le 1 ]
then
	echo "You have not enough monitors!"
	exit 2
fi

PRIMARYMONITOR=$(xrandr --listactivemonitors | grep -v "Monitors:" | awk '{print $2}' | grep "*" | sed "s/+//g" | sed "s/*//g")

if [ -z "${PRIMARYMONITOR}" ]
then
	echo "Non existent primary monitor!"
	exit 3
fi

MONITORLIST=$(xrandr --listactivemonitors | grep -v "Monitors:" | awk '{print $2}' | sed "s/+//g" | sed "s/*//g")

if [ -z "${MONITORLIST}" ]
then
	echo "XRandR cannot list monitors!"
	exit 4
fi

if [ "${ACTION}" == "duplicate" ]
then
	MAXMODE=$(maxmode)
	for i in ${MONITORLIST}
	do
		xrandr --output $i --mode ${MAXMODE}
		if ! [ "$i" == "${PRIMARYMONITOR}" ]
		then
			xrandr --output ${PRIMARYMONITOR} --same-as ${i}
		fi
	done
	exit 0
fi

if [ "${ACTION}" == "extend" ]
then
	LAST=${PRIMARYMONITOR}
	for i in ${MONITORLIST}
	do
		if ! [ "$i" == "${PRIMARYMONITOR}" ]
		then
			xrandr --output ${i} --left-of ${LAST}
			LAST=$i
		fi
	done
	exit 0
fi

echo "Unknown action: ${ACTION}"

usage
